vietmap_gl_platform_interface library

Classes

Annotation
ArgumentCallbacks<T>
Mutable collection of ArgumentCallback instances, itself an ArgumentCallback.
CameraPosition
The position of the map "camera", the view point from which the world is shown in the map view. Aggregates the camera's target geographical location, its zoom level, tilt angle, and bearing.
CameraTargetBounds
Bounds for the map camera target. Used with _MapLibreMapOptions to wrap a LatLngBounds value. This allows distinguishing between specifying an unbounded target (null LatLngBounds) from not specifying anything (null CameraTargetBounds).
CameraUpdate
Defines a camera move, supporting absolute moves as well as moves relative the current position.
Circle
CircleOptions
Configuration options for Circle instances.
GeojsonSourceProperties
ImageSourceProperties
LatLng
A pair of latitude and longitude coordinates, stored as degrees.
LatLngBounds
A latitude/longitude aligned rectangle.
LatLngQuad
A geographical area representing a non-aligned quadrilateral This class does not wrap values to the world bounds
Line
LocationEngineAndroidProperties
LocationEnginePlatforms
iOS is not supported at the moment.
MarkerLayerPositionData
MarkerPositionData
MethodChannelVietmapGl
MinMaxZoomPreference
Preferred bounds for map camera zoom level. Used with _MapLibreMapOptions to wrap min and max zoom. This allows distinguishing between specifying unbounded zooming (null minZoom and maxZoom) from not specifying anything (null MinMaxZoomPreference).
NearestLatLngResult
Polygon
PolygonOptions
Configuration options for Polygon instances.
PolylineOptions
Configuration options for Line instances.
RasterDemSourceProperties
RasterSourceProperties
SourceProperties
Symbol
SymbolOptions
Configuration options for Symbol instances.
UserHeading
Type represents a geomagnetic value, measured in microteslas, relative to a device axis in three dimensional space.
UserLocation
User's observed location
VectorSourceProperties
VideoSourceProperties
VietmapGlPlatform
VietmapMathUtil
VietmapPolygonUtil
Port of PolyUtil from android-maps-utils (https://github.com/googlemaps/android-maps-utils)
VietmapPolyline
VietmapPolylineDecoder
Decode the google encoded string using Encoded Polyline Algorithm Format for more info about the algorithm check https://developers.google.com/maps/documentation/utilities/polylinealgorithm
VietMapSnapEngine
Support snapping user location to route, tracking user's distance to route, etc.
VietmapSphericalUtil
Port of SphericalUtil from android-maps-utils (https://github.com/googlemaps/android-maps-utils)

Enums

AttributionButtonPosition
Attribution Button Position
CameraAnimationInterpolation
Easing curve applied by VietmapGlPlatform.easeCamera.
CompassViewPosition
Compass View Position
LocationPriority
An enum representing the priority for location accuracy and power usage.
MyLocationRenderMode
Specifies if and how the user's heading/bearing is rendered in the user location indicator.
MyLocationTrackingMode
The camera mode, which determines how the map camera will track the rendered location.
Unit

Constants

earthRadius → const double
factors → const Map<Unit, num>

Typedefs

ArgumentCallback<T> = void Function(T argument)
Callback function taking a single argument.
OnPlatformViewCreatedCallback = void Function(int)
The default instance of VietmapGlPlatform to use.